local character
local outline
local spotlight
local cx, cy, scx, scy, ccx, ccy

local vel = 180
local min, max = -300, 300
local x = min
local shader

function love.load()
  cx, cy = love.graphics.getWidth()/2, love.graphics.getHeight()/2
  character = love.graphics.newImage('Character.png')
  outline = love.graphics.newImage('CharacterOutline.png')
  spotlight = love.graphics.newImage('Spotlight.png')
  scx, scy = spotlight:getWidth()/2, spotlight:getHeight()/2
  -- outline:getDimensions() assumed to be equal to character:getDimensions()
  ccx, ccy = character:getWidth()/2, character:getHeight()/2

  shader = love.graphics.newShader[[
    vec4 effect(vec4 colour, Image texture, vec2 texpos, vec2 scrpos)
    {
      vec4 pixel = Texel(texture, texpos) * colour;
      if (pixel.a < 0.5) discard;
      return pixel;
    }
  ]]
end


function love.update(dt)
  x = x + vel * dt
  if x > max then x = x - (max - min) end
end



local function stencilFunction()
  love.graphics.setShader(shader)
  love.graphics.draw(spotlight, cx, cy, 0, 1, 1, scx, scy)
  love.graphics.setShader()
end


function love.draw()
  love.graphics.stencil(stencilFunction)
  love.graphics.translate(cx, cy)
  love.graphics.draw(spotlight, 0,0,  0,  1,1,  scx,scy)

  love.graphics.setStencilTest("equal", 1)
  love.graphics.draw(character, x,0,  0,  1,1,  ccx,ccy)
  love.graphics.setStencilTest("notequal", 1)
  love.graphics.draw(outline,   x,0,  0,  1,1,  ccx,ccy)
  love.graphics.setStencilTest("always", 0)
end

function love.keypressed(k) return k == "escape" and love.event.quit() end
